darkhistory.history.reionization.recomb\_cooling\_rate
======================================================

.. currentmodule:: darkhistory.history.reionization

.. autofunction:: recomb_cooling_rate